The documentation of all public classes, methods, and functions in the project 
can be found [here](abstochkin/index.html). 

A monograph detailing the theoretical underpinnings of the *Agent-based Kinetics* 
algorithm and a multitude of case studies highlighting its use can be found 
[here](Agent-basedKinetics_monograph.pdf).